==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/lt_LT.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Short rule description" : "Rodyti taisyklės aprašymą",
    "Add rule" : "Pridėti taisyklę",
    "Reset" : "Atstatyti",
    "Save" : "Įrašyti",
    "Saving…" : "Įrašoma…",
    "Group list is empty" : "Grupės sąrašas yra tuščias",
    "Unable to retrieve the group list" : "Nepavyko nuskaityti grupių sąrašo",
    "Saved" : "Įrašyta",
    "Saving failed:" : "Įrašymas nepavyko:",
    "Add rule group" : "Pridėti taisyklių grupę",
    "File MIME type" : "Failo MIME tipas",
    "is" : "yra",
    "is not" : "nėra",
    "matches" : "atitinka",
    "does not match" : "nesutapo",
    "Example: {placeholder}" : "Pavyzdys: {placeholder}",
    "File name" : "Failo pavadinimas",
    "File size (upload)" : "Failo dydis (įkėlimas)",
    "less" : "mažiau",
    "less or equals" : "mažiau arba lygu",
    "greater or equals" : "daugiau arba lygu",
    "greater" : "daugiau",
    "File system tag" : "Failų sistemos žymė",
    "is tagged with" : "pažymėtas",
    "is not tagged with" : "nepažymėtas",
    "Select tag…" : "Pasirinkite žymę…",
    "Request remote address" : "Užklausos nutolęs adresas",
    "matches IPv4" : "atitinka IPv4",
    "does not match IPv4" : "neatitinka IPv4",
    "matches IPv6" : "atitinka IPv6",
    "does not match IPv6" : "neatitinka IPv6",
    "Request time" : "Užklausos laikas",
    "between" : "tarp",
    "not between" : "nėra tarp",
    "Start" : "Pradžia",
    "End" : "Pabaiga",
    "Select timezone…" : "Pasirinkite laiko juostą…",
    "Request URL" : "Užklausos URL",
    "Predefined URLs" : "Apibrėžti URLs",
    "Files WebDAV" : "WebDAV failai",
    "Request user agent" : "Užklausos vartotojo agentas",
    "Sync clients" : "Sinchronizavimo klientas",
    "Android client" : "Android klientas",
    "iOS client" : "iOS klientas",
    "Desktop client" : "Darbalaukio klientas",
    "User group membership" : "Vartotojų grupių narystės",
    "is member of" : "priklauso",
    "is not member of" : "nepriklauso",
    "The given operator is invalid" : "Nurodytas operatorius yra neteisingas",
    "The given regular expression is invalid" : "Nurodyta reguliari išraiška neteisinga",
    "The given file size is invalid" : "Nurodytas failo dydis neteisingas",
    "The given tag id is invalid" : "Nurodyta žymė neteisinga",
    "The given IP range is invalid" : "Nurodytas IP rėžis nėra korektiškas",
    "The given IP range is not valid for IPv4" : "Nurodytas IPv4 adresas neteisingas",
    "The given IP range is not valid for IPv6" : "Nurodytas IPv6 adresas neteisingas",
    "The given time span is invalid" : "Neteisingai nurodytas laiko tarpsnis",
    "The given start time is invalid" : "Neteisingai nurodyta laiko pradžia",
    "The given end time is invalid" : "Neteisingai nurodyta laiko pabaiga",
    "The given group does not exist" : "Pateikta grupė neegzistuoja",
    "Check %s is invalid or does not exist" : "%s neteisingas arba neegzistuoja",
    "Operation #%s does not exist" : "Operacijos #%s nėra",
    "Operation %s does not exist" : "Operacijos %s nėra",
    "Operation %s is invalid" : "Neteisinga %s operacija",
    "Check %s does not exist" : "%s neegzistuoja",
    "Check %s is invalid" : "Neteisingas %s",
    "Check #%s does not exist" : "#%s neegzistuoja",
    "Workflow" : "Darbo eiga",
    "Files workflow engine" : "Darbo eigos su failais modulis",
    "Open documentation" : "Atverti dokumentaciją",
    "Loading…" : "Įkeliama…"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-15.0.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/lt_LT.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Short rule description" : "Rodyti taisyklės aprašymą",
    "Add rule" : "Pridėti taisyklę",
    "Reset" : "Atstatyti",
    "Save" : "Įrašyti",
    "Saving…" : "Įrašoma…",
    "Group list is empty" : "Grupės sąrašas yra tuščias",
    "Unable to retrieve the group list" : "Nepavyko nuskaityti grupių sąrašo",
    "Saved" : "Įrašyta",
    "Saving failed:" : "Įrašymas nepavyko:",
    "Add rule group" : "Pridėti taisyklių grupę",
    "File MIME type" : "Failo MIME tipas",
    "is" : "yra",
    "is not" : "nėra",
    "matches" : "atitinka",
    "does not match" : "nesutapo",
    "Example: {placeholder}" : "Pavyzdys: {placeholder}",
    "File name" : "Failo pavadinimas",
    "File size (upload)" : "Failo dydis (įkėlimas)",
    "less" : "mažiau",
    "less or equals" : "mažiau arba lygu",
    "greater or equals" : "daugiau arba lygu",
    "greater" : "daugiau",
    "File system tag" : "Failų sistemos žymė",
    "is tagged with" : "pažymėtas",
    "is not tagged with" : "nepažymėtas",
    "Select tag…" : "Pasirinkite žymę…",
    "Request remote address" : "Užklausos nutolęs adresas",
    "matches IPv4" : "atitinka IPv4",
    "does not match IPv4" : "neatitinka IPv4",
    "matches IPv6" : "atitinka IPv6",
    "does not match IPv6" : "neatitinka IPv6",
    "Request time" : "Užklausos laikas",
    "between" : "tarp",
    "not between" : "nėra tarp",
    "Start" : "Pradžia",
    "End" : "Pabaiga",
    "Select timezone…" : "Pasirinkite laiko juostą…",
    "Request URL" : "Užklausos URL",
    "Predefined URLs" : "Apibrėžti URLs",
    "Files WebDAV" : "WebDAV failai",
    "Request user agent" : "Užklausos vartotojo agentas",
    "Sync clients" : "Sinchronizavimo klientas",
    "Android client" : "Android klientas",
    "iOS client" : "iOS klientas",
    "Desktop client" : "Darbalaukio klientas",
    "User group membership" : "Vartotojų grupių narystės",
    "is member of" : "priklauso",
    "is not member of" : "nepriklauso",
    "The given operator is invalid" : "Nurodytas operatorius yra neteisingas",
    "The given regular expression is invalid" : "Nurodyta reguliari išraiška neteisinga",
    "The given file size is invalid" : "Nurodytas failo dydis neteisingas",
    "The given tag id is invalid" : "Nurodyta žymė neteisinga",
    "The given IP range is invalid" : "Nurodytas IP rėžis nėra korektiškas",
    "The given IP range is not valid for IPv4" : "Nurodytas IPv4 adresas neteisingas",
    "The given IP range is not valid for IPv6" : "Nurodytas IPv6 adresas neteisingas",
    "The given time span is invalid" : "Neteisingai nurodytas laiko tarpsnis",
    "The given start time is invalid" : "Neteisingai nurodyta laiko pradžia",
    "The given end time is invalid" : "Neteisingai nurodyta laiko pabaiga",
    "The given group does not exist" : "Pateikta grupė neegzistuoja",
    "Check %s is invalid or does not exist" : "%s neteisingas arba neegzistuoja",
    "Operation #%s does not exist" : "Operacijos #%s nėra",
    "Operation %s does not exist" : "Operacijos %s nėra",
    "Operation %s is invalid" : "Neteisinga %s operacija",
    "Check %s does not exist" : "%s neegzistuoja",
    "Check %s is invalid" : "Neteisingas %s",
    "Check #%s does not exist" : "#%s neegzistuoja",
    "Files workflow engine" : "Darbo eigos su failais modulis",
    "Open documentation" : "Atverti dokumentaciją",
    "Loading…" : "Įkeliama…",
    "Workflow" : "Darbo eiga"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
